---
title: Icons
page_title: Icons - PanelBar - Kendo UI for Vue
description: "Add images or predefined and custom icons to the Kendo UI PanelBar wrapper for Vue."
slug: icons_panelbar
position: 5
---

# Icons

You can add icons to the items of the PanelBar either through the `image-url` option or `sprite-css-class` attributes.

The following example demonstrates how to create a PanelBar with images.

{% meta height:550 %}
```html-preview
<div id="vueapp" class="vue-app">
    <kendo-panelbar>
        <kendo-panelbar-item text="Baseball" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/sports/baseball.png">
            <kendo-panelbar-item text="Top News" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/16/star.png"></kendo-panelbar-item>
            <kendo-panelbar-item text="Photo Galleries" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/16/photo.png"></kendo-panelbar-item>
            <kendo-panelbar-item text="Videos Records" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/16/video.png"></kendo-panelbar-item>
            <kendo-panelbar-item text="Radio Records" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/16/speaker.png"></kendo-panelbar-item>
        </kendo-panelbar-item>
        <kendo-panelbar-item text="Golf" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/sports/golf.png">
            <kendo-panelbar-item text="Top News" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/16/star.png"></kendo-panelbar-item>
            <kendo-panelbar-item text="Photo Galleries" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/16/photo.png"></kendo-panelbar-item>
            <kendo-panelbar-item text="Videos Records" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/16/video.png"></kendo-panelbar-item>
            <kendo-panelbar-item text="Radio Records" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/16/speaker.png"></kendo-panelbar-item>
        </kendo-panelbar-item>
        <kendo-panelbar-item text="Swimming" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/sports/swimming.png">
            <kendo-panelbar-item text="Top News" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/16/star.png"></kendo-panelbar-item>
            <kendo-panelbar-item text="Photo Galleries" image-url="https://demos.telerik.com/kendo-ui/content/shared/icons/16/photo.png"></kendo-trepanelbareview-item>
        </kendo-panelbar-item>
    </kendo-panelbar>
</div>
```
```js
Vue.use(LayoutInstaller);

new Vue({
    el: "#vueapp"
})
```
{% endmeta %}

The following example demonstrates how to create a PanelBar with sprites.

{% meta height:500 %}
```html-preview
<div id="vueapp" class="vue-app">
    <kendo-panelbar id="panelbar-sprites">
        <kendo-panelbar-item text="Brazil" sprite-css-class="brazilFlag" :items="[
            { text: 'History', spriteCssClass: 'historyIcon' },
            { text: 'Geography', spriteCssClass: 'geographyIcon' }
        ]" ></kendo-panelbar-item>
        <kendo-panelbar-item text="India" sprite-css-class="indiaFlag" :items="[
            { text: 'History', spriteCssClass: 'historyIcon' },
            { text: 'Geography', spriteCssClass: 'geographyIcon' }
        ]" ></kendo-panelbar-item>
        <kendo-panelbar-item text="Netherlands" sprite-css-class="netherlandsFlag" :items="[
            { text: 'History', spriteCssClass: 'historyIcon' },
            { text: 'Geography', spriteCssClass: 'geographyIcon' }
        ]" ></kendo-panelbar-item>
    </kendo-panelbar>
</div>
<style>
    .k-panel {
        -webkit-transform: translatez(0);
    }
    #panelbar-sprites .k-sprite {
        background-image: url("https://demos.telerik.com/kendo-ui/content/shared/styles/flags.png");
    }
    .brazilFlag {
        background-position: 0 0;
    }
    .indiaFlag {
        background-position: 0 -32px;
    }
    .netherlandsFlag {
        background-position: 0 -64px;
    }
    .historyIcon {
        background-position: 0 -96px;
    }
    .geographyIcon {
        background-position: 0 -128px;
    }
</style>
```
```js
Vue.use(LayoutInstaller);

new Vue({
    el: "#vueapp"
})
```
{% endmeta %}

## Suggested Links

* [Kendo UI PanelBar for jQuery](https://docs.telerik.com/kendo-ui/controls/navigation/panelbar/overview)
* [API Reference of the PanelBar Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/panelbar)
