---
title: Overview
page_title: PanelBar Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI PanelBar wrapper for Vue delivers and use the component in Vue projects."
slug: overview_panelbar
position: 1
---

# PanelBar Overview

The PanelBar displays hierarchical data in a multi-level, expandable format.

The PanelBar wrapper for Vue is a client-side wrapper for the [Kendo UI PanelBar](https://demos.telerik.com/kendo-ui/panelbar/index) widget.

## Basic Usage

The following example demonstrates the PanelBar in action.

```html-preview    
<div id="vueapp" class="vue-app">
    <kendo-panelbar>
       <li>
           Baseball
           <ul>
               <li>Top News</li>
               <li>Radio Records</li>
           </ul>
       </li>
       <li>
           Golf
           <ul>
               <li>Top News</li>
               <li>Radio Records</li>
           </ul>
       </li>
    </kendo-panelbar>
</div>
```
```js  
    Vue.use(LayoutInstaller);
    new Vue({ el: '#vueapp' })
```

## Functionality and Features

* [Setting the DataSource]({% slug data_source_settings_panelbar %})
* [Data binding]({% slug databinding_panelbar %})
* [Animation effects]({% slug animation_effects_panelbar %})
* [Icons]({% slug icons_panelbar %})
* [Templates]({% slug templates_panelbar %})
* [Loading content with AJAX]({% slug loading_content_ajax_panelbar %})
* [Keyboard navigation]({% slug keyboard_navigation_panelbar %})
* [RTL support]({% slug rtl_support_panelbar %})

## Events

The following example demonstrates basic PanelBar events. You can subscribe to [all PanelBar events](https://docs.telerik.com/kendo-ui/api/javascript/ui/panelbar#events) by the handler name.

```html    
<div id="vueapp">
<kendo-panelbar @select="onSelect">
    <li>
    Item 1
        <ul>
            <li>Sub Item 1
                <ul>
                    <li>Sub Item 1.1</li>
                    <li>Sub Item 1.2</li>
                    <li>Sub Item 1.3</li>
                </ul>
            </li>
            <li>Sub Item 2</li>
            <li>Sub Item 3</li>
        </ul>
    </li>
    <li>
        Item 2
        <ul>
            <li>Sub Item 1</li>
            <li>Sub Item 2</li>
            <li>Sub Item 3</li>
        </ul>
    </li>
</kendo-panelbar>
</div>
```
```js    
    Vue.use(LayoutInstaller);
    new Vue({
        el: '#vueapp',
        methods: {
            onSelect: function (e) {
                var selectedItem = $(e.item);
                console.log("Selected item : " + selectedItem.text());
            }
        }
    })
```

## Suggested Links

* [Kendo UI PanelBar for jQuery](https://docs.telerik.com/kendo-ui/controls/navigation/panelbar/overview)
* [API Reference of the PanelBar Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/panelbar)
